import java.io.*;
import java.util.*;

/* Diese Klasse stellt diverse Ein- und Ausgabemglichkeiten
 * zur Verfgung.
 * Autor: Peter Schneider-Kamp, Ren Thiemann, Thomas Weiler
 * Erstellt: 23.10.2003
 * Letzte nderung: 17.11.2003
 */

public class IO {

    // lese eine Zeile aus der Standardeingabe
    public static String readLine() {
        try {
            return new BufferedReader(new InputStreamReader(System.in)).readLine();
        } catch (IOException io) {
            System.err.println("IO-Fehler!");
            return "";
        }
    }

    // lese ein Array von Integern aus der Standardeingabe
    public static int[] readIntArray() {
	String line;
	try {
	    line = IO.readLine().trim();
	    if (line.equals("")) {
		return new int[0];
	    }
	    String parts[] = line.split(" +");
	    int result[] = new int[parts.length];
	    for (int i = 0; i<parts.length; i++) {
		result[i] = Integer.parseInt(parts[i]);
	    }
	    return result;
	} catch (NumberFormatException e) {
	    System.err.println("Keine Zahl!");
	    return new int[0];
	}
    }
	

    /*
     * Liest einen Double-Wert von der Standardeingabe.
     * Dabei kann sowohl ein Punkt als auch ein Komma als
     * Dezimaltrennzeichen verwendet werden.
     */ 
    public static double readDouble(){
	double d = 0;
	try {
	    String eingabe = IO.readLine();
	    eingabe = eingabe.replaceAll(",",".");
	    d = Double.parseDouble(eingabe);
	} catch (NumberFormatException e) {
	    System.err.println("Keine Gleitkommazahl!");
	}
	return d;
    }
    

    // lese einen Integer aus der Standardeingabe
    public static int readInt() {
        try {
            return Integer.parseInt(IO.readLine());
        } catch (NumberFormatException e) {
            System.err.println("Keine Zahl!");
            return 0;
        }
    }

    // fr Abwrtskompatibilitt mit alter IO.java
    public static int eingabe() {
        return IO.readInt();
    }

    // gibt eine Matrix von Integer-Zahlen aus
    public static void printIntMatrix(int m[][]) {
	for (int i=0; i < m.length; i++) {
	    printIntArray(m[i]);
	}
    }

    // gibt ein Array von Integer-Zahlen aus
    public static void printIntArray(int z[]) {
	for (int i = 0; i < z.length; i++) {
	    System.out.print(z[i]+" ");
	}
	System.out.println();
    }

    // gibt ein Array von Objekten aus
    public static void printArray(Object z[]) {
	System.out.print("[");
	if (z.length > 0) {
	    System.out.print(z[0]);
	}
	for (int i = 1; i < z.length; i++) {
	    System.out.print(", "+z[i]);
	}
	System.out.println("]");
    }
    
    // lese ein ganzes File in ein String-Array ein
    // eine Zeile entspricht dann einem Eintrag in dem Array
    // liefert null zurueck, falls das File nicht gelesen werden konnte
    public static String[] readFile(String fileName) {
	Vector vec = new Vector();
	try {
	    BufferedReader bufReader = new BufferedReader(new FileReader(fileName));
	    while (bufReader.ready()) {
		vec.add(bufReader.readLine());
	    }
	} catch (Exception e) {
	    System.err.println("Some error occured reading file <"+fileName+">!");
	    return null;
	}
	String result[] = new String[vec.size()];
	Iterator i = vec.iterator();
	int counter = 0;
	while (i.hasNext()) {
	    result[counter] = (String) i.next();
	    counter++;
	}
	return result;
    }
}

